===================================
A note about the discussion section
===================================

This section is meant as an area of the documentation meant for discussion of
the implementation of various aspects of nitime, including API and analysis.

However, it does not necessarily reflect the current state of the
software. Some things may be implemented differently than described here, or
not implemented at all.

For documentation oriented at actual usage of the software, please refer to
:ref:`users-guide` and :ref:`examples`

